#!/bin/bash

# Check if the file argument is provided
if [ $# -eq 0 ]; then
  echo "Usage: $0 <filename>"
  exit 1
fi

# Read the timestamps from the file into an array
readarray -t timestamps < "$1"

# Loop through each timestamp and extract the hour part
hours=()
for timestamp in "${timestamps[@]}"; do
  hour=$(date -d "$timestamp" +"%H")
  hours+=("$hour")
done

# Count the occurrences of each hour
declare -A counts
for hour in "${hours[@]}"; do
  (( counts[$hour]++ ))
done

# Find the maximum count
max_count=0
for hour in "${!counts[@]}"; do
  if [ ${counts[$hour]} -gt $max_count ]; then
    max_count=${counts[$hour]}
  fi
done

# Calculate the width of the histogram
hist_width=$(( 4 * ${#counts[@]} + 2 ))

# Print the top frame line
printf "+%-*s+\n" "$hist_width" | tr ' ' '-'

# Print the histogram
for ((i=max_count; i>0; i--)); do
  printf "|"
  for hour in "${!counts[@]}"; do
    if [ ${counts[$hour]} -ge $i ]; then
      printf "# "
    else
      printf "  "
    fi
  done
  printf "|\n"
done

# Print the bottom frame line
printf "+%-*s+\n" "$hist_width" | tr ' ' '-'

# Print the hour labels
printf "| %-*s|\n" "$hist_width" "${!counts[@]}"

# Print the bottom frame line
printf "+%-*s+\n" "$hist_width" | tr ' ' '-'
